==> core-react-0.8.0.tgz: package/es/Popover/PopoverContent.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import classlist from 'classlist';
import cx from 'classnames';
import CoordinateFactory from './CoordinateFactory';

var PopoverContent = /*#__PURE__*/function (_Component) {
  _inherits(PopoverContent, _Component);

  function PopoverContent() {
    _classCallCheck(this, PopoverContent);

    return _possibleConstructorReturn(this, _getPrototypeOf(PopoverContent).apply(this, arguments));
  }

  _createClass(PopoverContent, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        popoverContent: this
      };
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.setPosition();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.setPosition();
    }
  }, {
    key: "setPosition",
    value: function setPosition() {
      var _cx;

      var _this$props = this.props,
          triggerNode = _this$props.triggerNode,
          direction = _this$props.direction,
          align = _this$props.align;
      var rootNode = ReactDOM.findDOMNode(this);
      rootNode.style.display = 'block'; // Prevent accumulation

      if (this.positionClassNames) {
        var _classlist;

        (_classlist = classlist(rootNode)).remove.apply(_classlist, _toConsumableArray(this.positionClassNames.split(' ')));
      }

      var _CoordinateFactory = CoordinateFactory(triggerNode, rootNode, direction, align),
          _CoordinateFactory2 = _slicedToArray(_CoordinateFactory, 2),
          computedDirection = _CoordinateFactory2[0],
          computedAlign = _CoordinateFactory2[1];

      this.positionClassNames = cx((_cx = {}, _defineProperty(_cx, "".concat("waui", "-popover_").concat(computedDirection), true), _defineProperty(_cx, "".concat("waui", "-popover_align-").concat(computedAlign), !!computedAlign), _cx));
      classlist(rootNode).add(this.positionClassNames);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          triggerNode = _this$props2.triggerNode,
          triggerMode = _this$props2.triggerMode,
          direction = _this$props2.direction,
          align = _this$props2.align,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "triggerNode", "triggerMode", "direction", "align"]);

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-popover"), _defineProperty({}, "".concat("waui", "-popover_animation"), triggerMode === 'hover'), className)
      }, other), React.createElement("div", {
        className: "".concat("waui", "-popover__content")
      }, children));
    }
  }]);

  return PopoverContent;
}(Component);

PopoverContent.propTypes = {
  children: PropTypes.oneOfType([PropTypes.string, PropTypes.array, PropTypes.element]),
  triggerNode: PropTypes.object,
  className: PropTypes.string,
  triggerMode: PropTypes.oneOf(['click', 'hover']),
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle'])
};
PopoverContent.childContextTypes = {
  popoverContent: PropTypes.instanceOf(PopoverContent)
};
export default PopoverContent;

==> core-react-0.8.2.tgz: package/es/Popover/PopoverContent.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import classlist from 'classlist';
import cx from 'classnames';
import CoordinateFactory from './CoordinateFactory';

var PopoverContent = /*#__PURE__*/function (_Component) {
  _inherits(PopoverContent, _Component);

  function PopoverContent() {
    _classCallCheck(this, PopoverContent);

    return _possibleConstructorReturn(this, _getPrototypeOf(PopoverContent).apply(this, arguments));
  }

  _createClass(PopoverContent, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        popoverContent: this
      };
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.setPosition();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.setPosition();
    }
  }, {
    key: "setPosition",
    value: function setPosition() {
      var _cx;

      var _this$props = this.props,
          triggerNode = _this$props.triggerNode,
          direction = _this$props.direction,
          align = _this$props.align;
      var rootNode = ReactDOM.findDOMNode(this);
      rootNode.style.display = 'block'; // Prevent accumulation

      if (this.positionClassNames) {
        var _classlist;

        (_classlist = classlist(rootNode)).remove.apply(_classlist, _toConsumableArray(this.positionClassNames.split(' ')));
      }

      var _CoordinateFactory = CoordinateFactory(triggerNode, rootNode, direction, align),
          _CoordinateFactory2 = _slicedToArray(_CoordinateFactory, 2),
          computedDirection = _CoordinateFactory2[0],
          computedAlign = _CoordinateFactory2[1];

      this.positionClassNames = cx((_cx = {}, _defineProperty(_cx, "".concat("waui", "-popover_").concat(computedDirection), true), _defineProperty(_cx, "".concat("waui", "-popover_align-").concat(computedAlign), !!computedAlign), _cx));
      classlist(rootNode).add(this.positionClassNames);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          triggerNode = _this$props2.triggerNode,
          triggerMode = _this$props2.triggerMode,
          direction = _this$props2.direction,
          align = _this$props2.align,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "triggerNode", "triggerMode", "direction", "align"]);

      return (/*#__PURE__*/React.createElement("div", _extends({
          className: cx("".concat("waui", "-popover"), _defineProperty({}, "".concat("waui", "-popover_animation"), triggerMode === 'hover'), className)
        }, other), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-popover__content")
        }, children))
      );
    }
  }]);

  return PopoverContent;
}(Component);

PopoverContent.propTypes = {
  children: PropTypes.oneOfType([PropTypes.string, PropTypes.array, PropTypes.element]),
  triggerNode: PropTypes.object,
  className: PropTypes.string,
  triggerMode: PropTypes.oneOf(['click', 'hover']),
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle'])
};
PopoverContent.childContextTypes = {
  popoverContent: PropTypes.instanceOf(PopoverContent)
};
export default PopoverContent;
